@@ -15,11 +15,6 @@ class EsRequest:
         self.user = user
         # 密码
         self.password = password
-        try:
-            request = importlib.import_module("lesscode_utils.request")
-        except ImportError as e:
-            raise Exception(f"lesscode_utils is not exist,run:pip install lesscode_utils")
-        self.auth = request.get_basic_auth(user, password)
         host_str = host.split(",")
         self.hosts = [host for host in host_str]
 
@@ -37,9 +32,11 @@ class EsRequest:
             url = url_func_str(**param_dict)
             try:
                 if request_way == "get":
-                    res = request.sync_common_get(url, params=find_condition, result_type="json", auth=self.auth)
+                    res = request.sync_common_get(url, params=find_condition, result_type="json",
+                                                  auth=request.get_basic_auth(self.user, self.password))
                 elif request_way == "post":
-                    res = request.sync_common_post(url, json=find_condition, result_type="json", auth=self.auth)
+                    res = request.sync_common_post(url, json=find_condition, result_type="json",
+                                                   auth=request.get_basic_auth(self.user, self.password))
                 if res:
                     if res.get("took"):
                         break
@@ -63,20 +60,20 @@ class EsRequest:
         if methd.lower() == "post":
             res = request.sync_common_post(url, json=body, params=params, headers={'content-type': "application/json"},
                                            result_type="json",
-                                           auth=self.auth, timeout=None)
+                                           auth=request.get_basic_auth(self.user, self.password), timeout=None)
         elif methd.lower() == "get":
             res = request.sync_common_get(url, json=body, params=params, headers={'content-type': "application/json"},
                                           result_type="json",
-                                          auth=self.auth, timeout=None)
+                                          auth=request.get_basic_auth(self.user, self.password), timeout=None)
         elif methd.lower() == "put":
             res = request.sync_common_put(url, json=body, params=params, headers={'content-type': "application/json"},
                                           result_type="json",
-                                          auth=self.auth, timeout=None)
+                                          auth=request.get_basic_auth(self.user, self.password), timeout=None)
         elif methd.lower() == "delete":
             res = request.sync_common_delete(url, json=body, params=params,
                                              headers={'content-type': "application/json"},
                                              result_type="json",
-                                             auth=self.auth, timeout=None)
+                                             auth=request.get_basic_auth(self.user, self.password), timeout=None)
         return res
 
     def format_scroll_url(self, host=None, port=None, route_key=None, scroll=None):
